@@ -1,6 +1,6 @@
 /* gridfs.c */
 
-/*    Copyright 2009-2011 10gen Inc.
+/*    Copyright 2009-2012 10gen Inc.
  *
  *    Licensed under the Apache License, Version 2.0 (the "License");
  *    you may not use this file except in compliance with the License.
@@ -21,7 +21,7 @@
 #include <string.h>
 #include <assert.h>
 
-MONGO_EXPORT gridfs* gridfs_create() {
+MONGO_EXPORT gridfs* gridfs_create( void ) {
     return (gridfs*)bson_malloc(sizeof(gridfs));
 }
 
@@ -29,7 +29,7 @@ MONGO_EXPORT void gridfs_dispose(gridfs* gfs) {
     free(gfs);
 }
 
-MONGO_EXPORT gridfile* gridfile_create() {
+MONGO_EXPORT gridfile* gridfile_create( void ) {
     return (gridfile*)bson_malloc(sizeof(gridfile));
 }
 
@@ -170,7 +170,7 @@ static int gridfs_insert_file( gridfs *gfs, const char *name,
         bson_append_string( &ret, "contentType", contenttype );
     }
     bson_finish( &ret );
-    result = mongo_insert( gfs->client, gfs->files_ns, &ret );
+    result = mongo_insert( gfs->client, gfs->files_ns, &ret, NULL );
     bson_destroy( &ret );
 
     return result;
@@ -198,7 +198,7 @@ MONGO_EXPORT int gridfs_store_buffer( gridfs *gfs, const char *data,
         chunkLen = DEFAULT_CHUNK_SIZE < ( unsigned int )( end - data_ptr ) ?
                    DEFAULT_CHUNK_SIZE : ( unsigned int )( end - data_ptr );
         oChunk = chunk_new( id, chunkNumber, data_ptr, chunkLen );
-        mongo_insert( gfs->client, gfs->chunks_ns, oChunk );
+        mongo_insert( gfs->client, gfs->chunks_ns, oChunk, NULL );
         chunk_free( oChunk );
         chunkNumber++;
         data_ptr += chunkLen;
@@ -248,21 +248,20 @@ MONGO_EXPORT void gridfile_write_buffer( gridfile *gfile, const char *data,
 
     }
     else {   /* At least one chunk of data to write */
+        chunks_to_write = to_write / DEFAULT_CHUNK_SIZE;
+        bytes_left = to_write % DEFAULT_CHUNK_SIZE;
 
         /* If there's a pending chunk to be written, we need to combine
          * the buffer provided up to DEFAULT_CHUNK_SIZE.
          */
         if ( gfile->pending_len > 0 ) {
-            chunks_to_write = to_write / DEFAULT_CHUNK_SIZE;
-            bytes_left = to_write % DEFAULT_CHUNK_SIZE;
-
             data_partial_len = DEFAULT_CHUNK_SIZE - gfile->pending_len;
             buffer = ( char * )bson_malloc( DEFAULT_CHUNK_SIZE );
             memcpy( buffer, gfile->pending_data, gfile->pending_len );
             memcpy( buffer + gfile->pending_len, data, data_partial_len );
 
             oChunk = chunk_new( gfile->id, gfile->chunk_num, buffer, DEFAULT_CHUNK_SIZE );
-            mongo_insert( gfile->gfs->client, gfile->gfs->chunks_ns, oChunk );
+            mongo_insert( gfile->gfs->client, gfile->gfs->chunks_ns, oChunk, NULL );
             chunk_free( oChunk );
             gfile->chunk_num++;
             gfile->length += DEFAULT_CHUNK_SIZE;
@@ -275,7 +274,7 @@ MONGO_EXPORT void gridfile_write_buffer( gridfile *gfile, const char *data,
 
         while( chunks_to_write > 0 ) {
             oChunk = chunk_new( gfile->id, gfile->chunk_num, data, DEFAULT_CHUNK_SIZE );
-            mongo_insert( gfile->gfs->client, gfile->gfs->chunks_ns, oChunk );
+            mongo_insert( gfile->gfs->client, gfile->gfs->chunks_ns, oChunk, NULL );
             chunk_free( oChunk );
             gfile->chunk_num++;
             chunks_to_write--;
@@ -305,7 +304,7 @@ MONGO_EXPORT int gridfile_writer_done( gridfile *gfile ) {
     int response;
     if( gfile->pending_data ) {
         oChunk = chunk_new( gfile->id, gfile->chunk_num, gfile->pending_data, gfile->pending_len );
-        mongo_insert( gfile->gfs->client, gfile->gfs->chunks_ns, oChunk );
+        mongo_insert( gfile->gfs->client, gfile->gfs->chunks_ns, oChunk, NULL );
         chunk_free( oChunk );
         bson_free( gfile->pending_data );
         gfile->length += gfile->pending_len;
@@ -347,7 +346,7 @@ int gridfs_store_file( gridfs *gfs, const char *filename,
     chunkLen = fread( buffer, 1, DEFAULT_CHUNK_SIZE, fd );
     do {
         oChunk = chunk_new( id, chunkNumber, buffer, chunkLen );
-        mongo_insert( gfs->client, gfs->chunks_ns, oChunk );
+        mongo_insert( gfs->client, gfs->chunks_ns, oChunk, NULL );
         chunk_free( oChunk );
         length += chunkLen;
         chunkNumber++;
@@ -394,14 +393,14 @@ MONGO_EXPORT void gridfs_remove_filename( gridfs *gfs, const char *filename ) {
         bson_init( &b );
         bson_append_oid( &b, "_id", &id );
         bson_finish( &b );
-        mongo_remove( gfs->client, gfs->files_ns, &b );
+        mongo_remove( gfs->client, gfs->files_ns, &b, NULL );
         bson_destroy( &b );
 
         /* Remove all chunks from the file with the specified id */
         bson_init( &b );
         bson_append_oid( &b, "files_id", &id );
         bson_finish( &b );
-        mongo_remove( gfs->client, gfs->chunks_ns, &b );
+        mongo_remove( gfs->client, gfs->chunks_ns, &b, NULL );
         bson_destroy( &b );
     }
 
@@ -472,7 +471,7 @@ MONGO_EXPORT void gridfile_destroy( gridfile *gfile )
 }
 
 bson_bool_t gridfile_exists( gridfile *gfile ) {
-    return ( bson_bool_t )( gfile != NULL || gfile->meta == NULL );
+    return ( bson_bool_t )( gfile != NULL && gfile->meta != NULL );
 }
 
 MONGO_EXPORT const char *gridfile_get_filename( gridfile *gfile ) {
@@ -649,7 +648,7 @@ gridfs_offset gridfile_write_file( gridfile *gfile, FILE *stream ) {
         bson_find( &it, &chunk, "data" );
         len = bson_iterator_bin_len( &it );
         data = bson_iterator_bin_data( &it );
-        fwrite( data , sizeof( char ), len, stream );
+        fwrite( data, sizeof( char ), len, stream );
         bson_destroy( &chunk );
     }
 
