@@ -59,6 +59,7 @@
  * run on either big- or little-endian CPUs, but will run slightly less
  * efficiently on either one than if ARCH_IS_BIG_ENDIAN is defined.
  */
+#include "bson.h"
 
 typedef unsigned char mongo_md5_byte_t; /* 8-bit byte */
 typedef unsigned int mongo_md5_word_t; /* 32-bit word */
@@ -76,13 +77,13 @@ extern "C"
 #endif
 
     /* Initialize the algorithm. */
-    void mongo_md5_init(mongo_md5_state_t *pms);
+    MONGO_EXPORT void mongo_md5_init(mongo_md5_state_t *pms);
 
     /* Append a string to the message. */
-    void mongo_md5_append(mongo_md5_state_t *pms, const mongo_md5_byte_t *data, int nbytes);
+    MONGO_EXPORT void mongo_md5_append(mongo_md5_state_t *pms, const mongo_md5_byte_t *data, int nbytes);
 
     /* Finish the message and return the digest. */
-    void mongo_md5_finish(mongo_md5_state_t *pms, mongo_md5_byte_t digest[16]);
+    MONGO_EXPORT void mongo_md5_finish(mongo_md5_state_t *pms, mongo_md5_byte_t digest[16]);
 
 #ifdef __cplusplus
 }  /* end extern "C" */
